.. _utils:

Utility functions
=================

Data validation
---------------
.. currentmodule:: skchange.utils.validation.data

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    check_data

Cuts validation
---------------

.. currentmodule:: skchange.utils.validation.cuts

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    check_cuts_array


Parameter validation
--------------------
.. currentmodule:: skchange.utils.validation.parameters

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    check_larger_than
    check_smaller_than
    check_in_interval

Plotting
--------
.. currentmodule:: skchange.utils.plotting

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    plot_detections
    plot_scatter_segmentation
